@@ -1296,9 +1296,9 @@ class MibTableRow(MibTree):
             # rfc1902, 7.7
             if impliedFlag:
                 return obj.clone(tuple(value)), ()
-            elif obj.isFixedLength():
-                value = obj.getFixedLength()
-                return obj.clone(tuple(value[:value])), value[value:]
+            elif obj.is_fixed_length():
+                fixed_length = obj.get_fixed_length()
+                return obj.clone(tuple(value[:fixed_length])), value[fixed_length:]
             else:
                 return obj.clone(tuple(value[1 : value[0] + 1])), value[value[0] + 1 :]
         elif baseTag == self.__oidBaseTag:
@@ -1324,7 +1324,7 @@ class MibTableRow(MibTree):
         elif self.__ipaddrTagSet.isSuperTagSetOf(obj.getTagSet()):
             return obj.asNumbers()
         elif baseTag == self.__strBaseTag:
-            if impliedFlag or obj.isFixedLength():
+            if impliedFlag or obj.is_fixed_length():
                 initial = ()
             else:
                 initial = (len(obj),)
